magneticalc.Metric_Presets.Metric_Presets

# ``magneticalc`.`Metric_Presets`.`Metric_Presets``

class documentation

`class Metric_Presets:`

View In Hierarchy

Metric_Presets class.

Static Method | `get_by_id` | Selects a preset by name.
Class Variable | `AngleXY` | Undocumented
Class Variable | `AngleXZ` | Undocumented
Class Variable | `AngleYZ` | Undocumented
Class Variable | `Divergence` | Undocumented
Class Variable | `List` | Undocumented
Class Variable | `LogDivergence` | Undocumented
Class Variable | `LogMagnitude` | Undocumented
Class Variable | `LogMagnitudeX` | Undocumented
Class Variable | `LogMagnitudeXY` | Undocumented
Class Variable | `LogMagnitudeXZ` | Undocumented
Class Variable | `LogMagnitudeY` | Undocumented
Class Variable | `LogMagnitudeYZ` | Undocumented
Class Variable | `LogMagnitudeZ` | Undocumented
Class Variable | `Magnitude` | Undocumented
Class Variable | `MagnitudeX` | Undocumented
Class Variable | `MagnitudeXY` | Undocumented
Class Variable | `MagnitudeXZ` | Undocumented
Class Variable | `MagnitudeY` | Undocumented
Class Variable | `MagnitudeYZ` | Undocumented
Class Variable | `MagnitudeZ` | Undocumented
Class Variable | `NegDivergence` | Undocumented
Class Variable | `NegLogDivergence` | Undocumented
Class Variable | `PosDivergence` | Undocumented
Class Variable | `PosLogDivergence` | Undocumented

@staticmethod
def get_by_id(_id_: `str`) -> `dict`:

Selects a preset by name.

Parameters
_id_: `str` | Preset ID

Returns
`dict` | Preset parameters

AngleXY =

Undocumented

AngleXZ =

Undocumented

AngleYZ =

Undocumented

Divergence =

Undocumented

List =

Undocumented

LogDivergence =

Undocumented

LogMagnitude =

Undocumented

LogMagnitudeX =

Undocumented

LogMagnitudeXY =

Undocumented

LogMagnitudeXZ =

Undocumented

LogMagnitudeY =

Undocumented

LogMagnitudeYZ =

Undocumented

LogMagnitudeZ =

Undocumented

Magnitude =

Undocumented

MagnitudeX =

Undocumented

MagnitudeXY =

Undocumented

MagnitudeXZ =

Undocumented

MagnitudeY =

Undocumented

MagnitudeYZ =

Undocumented

MagnitudeZ =

Undocumented

NegDivergence =

Undocumented

NegLogDivergence =

Undocumented

PosDivergence =

Undocumented

PosLogDivergence =

Undocumented